package com.kjj.qa.cases;

import static com.kjj.qa.config.BasicConfig.*;
import com.kjj.qa.utils.NetworkUtil;
import io.restassured.response.Response;
import org.testng.Assert;
import org.testng.annotations.*;
import org.testng.annotations.Test;


import java.io.IOException;
import java.util.HashMap;
import java.util.Map;



public class Pay {
    NetworkUtil network = NetworkUtil.getInstance();

    @BeforeClass
    public static void setUp() {

    }

    @Test (description = "默认付费_付费页",priority = 1) //priorty 方法执行优先级
    public void 默认付费_付费页() throws IOException {
        //付款中间页判断
        Response skipTypeResponse = network.getResponse(PAY_GETMIDDLEDETAIL);
        int skipType = skipTypeResponse.jsonPath().getInt("data.skipType");
        Assert.assertEquals(skipType,2,network.message(PAY_GETMIDDLEDETAIL,"付款中间页:不是2020新版"));

        //会销资格判断
        Response SiteSaleValidresponse = network.getResponse(PAY_HASSITESALEVALID);
        boolean siteSaleValid = SiteSaleValidresponse.jsonPath().getBoolean("data");
        Assert.assertEquals(siteSaleValid,false,network.message(PAY_HASSITESALEVALID,"会销资格判断:判断错误,有会销资格"));

        //会员类型版本判断
        Map<String, Object> params = new HashMap<String, Object>();
        params.put("t",System.currentTimeMillis());
        Response userVersionResponse = network.getResponse(params, VERSION_INFO);
        int userVersion = userVersionResponse.jsonPath().getInt("data.find {it.openType == 1}.userVersion"); // 找出开启状态的版本类型
        Assert.assertEquals(userVersion,1,network.message(params, VERSION_INFO,"会员类型版本判断:判断错误,此版本为保险版"));


        //获取当前用户可用优惠码
        Response promoCodeResponse = network.getResponse(params,PAY_GETPROMOCODE);
        String promoCode = promoCodeResponse.jsonPath().getString("data");
        Assert.assertEquals(promoCode,null, network.message(params,PAY_GETPROMOCODE,"是否优惠判断:判断错误,当前有优惠"));

        //获取付费价格
//        Response actualPayMoneyResponse = network.getResponse(PAY_COMBOLIST);
//        String actualPayMoney = actualPayMoneyResponse.jsonPath().getString("data[0].actualPayMoney");
//        Assert.assertEquals(actualPayMoney,"586",network.message(PAY_COMBOLIST,"获取付费价格:价格不是586"));
    }

    @Test (description = "默认付费_待支付",priority = 2)
    public void 默认付费_待支付() throws IOException {
        //创建支付
        Map<String, Object> payParams = new HashMap<String, Object>();
        payParams.put("userVersion",1);
        payParams.put("comboId","Kj21MTU");
        payParams.put("oaId","1");
        payParams.put("paySource","2");
        payParams.put("sellerFrom","");

        Response orderAppId = network.postResponse(payParams,PAY_ORDERCREATE);
        String appId = orderAppId.jsonPath().getString("data.appId");
        Assert.assertEquals(appId,"wxcb8c36279dd7dff2",network.message(payParams, PAY_ORDERCREATE,"拉起支付:拉起微信支付失败"));  //判断返回的微信调起参数中appId是否正确

    }

    @Test (description = "默认付费_取消支付",priority = 3)
    public void 默认付费_取消支付() throws IOException {
        //创建支付
        Map<String, Object> payParams = new HashMap<String, Object>();
        payParams.put("userVersion",1);
        payParams.put("comboId","Kj21MTU");
        payParams.put("oaId","1");
        payParams.put("paySource","2");
        payParams.put("sellerFrom","");
        Response orderAppId = network.postResponse(payParams,PAY_ORDERCREATE);
        String tradeNo = orderAppId.jsonPath().getString("data.tradeNo");

        //会员类型版本判断
        Map<String, Object> cancelParams = new HashMap<String, Object>();
        cancelParams.put("tradeNo",tradeNo);
        Response resultResponse = network.getResponse(cancelParams,PAY_ORDERCANCEL);
        String result = resultResponse.jsonPath().getString("desc");
        Assert.assertEquals(result,"OK",network.message(cancelParams, PAY_ORDERCANCEL,"取消支付：取消支付失败"));  //判断返回的微信调起参数中appId是否正确
    }

//    @Test (description = "默认付费_成功支付",priority = 4)
//    public void 默认付费_成功支付() throws IOException {
//
//    }

    @Test (description = "默认付费_切换会员类型为保险版",priority = 5)
    public void 默认付费_切换为保险版会员类型并成功付款() throws IOException {
        //会员类型版本判断
        Map<String, Object> params = new HashMap<String, Object>();
        params.put("t",System.currentTimeMillis());
        Response userVersionResponse = network.getResponse(params,VERSION_INFO);
        int userVersion = userVersionResponse.jsonPath().getInt("data.find {it.openType == 1}.userVersion"); // 找出开启状态的版本类型
        int changeVersion = userVersion == 1 ? 2 : 1; // 判断当前开启的版本，如果当前版本是1，则改为2，反之；


        //切换版本
        Map<String, Object> versionParams = new HashMap<String, Object>();
        versionParams.put("targetVersion",changeVersion);
        Response resultResponse = network.postResponse(versionParams,PAY_VERSIONEXCHANGE);
        String result = resultResponse.jsonPath().getString("desc");
        Assert.assertEquals(result,"OK",network.message(versionParams,PAY_VERSIONEXCHANGE,"会员类型切换:切换失败"));  //判断返回的微信调起参数中appId是否正确

        //会员类型再次判断
        params.put("t",System.currentTimeMillis());
        userVersionResponse = network.getResponse(params,VERSION_INFO);
        userVersion = userVersionResponse.jsonPath().getInt("data.find {it.openType == 1}.userVersion"); // 找出开启状态的版本类型
        Assert.assertEquals(userVersion,changeVersion,network.message(params, VERSION_INFO,"会员类型版本判断:判断错误，此版本为尊享版"));
    }

    @Test (description = "邀请码/分销码_付费页",priority = 6)
    public void 分销码_付费页() throws IOException {
        //用户绑定分销关系
        // 绑定一个上级为保险版的会员，scId和inviterSid可以在用户分享的链接里拿到
        Map<String, Object> distributeParams = new HashMap<String, Object>();
        distributeParams.put("inviterSid","1861"); //销售ID：1861加密后 会员邀请好友付费时，传此参数
        distributeParams.put("fromStr",1);                   //文章来源: 6文章访客转化  1会员邀请
        distributeParams.put("accessSource",22);             //支付来源：客集集
        Response distributeResponse = network.getResponse(distributeParams, PAY_DISTRIBUTE);
        String result = distributeResponse.jsonPath().getString("desc");
        Assert.assertEquals(result,"OK",network.message(distributeParams, PAY_DISTRIBUTE,"绑定分销状态:绑定失败"));  //判断返回的微信调起参数中appId是否正确

        //会员类型版本判断
        Map<String, Object> params = new HashMap<String, Object>();
        params.put("t",System.currentTimeMillis());
        Response userVersionResponse = network.getResponse(params,VERSION_INFO);
        int userVersion = userVersionResponse.jsonPath().getInt("data.find {it.openType == 1}.userVersion"); // 找出开启状态的版本类型，version应该类型为2
        Assert.assertEquals(userVersion,2,network.message(params, VERSION_INFO,"会员类型版本判断:判断错误,此版本不是上级对应的版本"));

        //获取当前用户可用优惠码
        Response promoCodeResponse = network.getResponse(params,PAY_GETPROMOCODE);
        String promoCode = promoCodeResponse.jsonPath().getString("data");
        Assert.assertEquals(promoCode,null,network.message(params, PAY_GETPROMOCODE,"是否优惠判断:判断错误,当前有优惠"));

        //获取付费价格
//        Response actualPayMoneyResponse = network.getResponse("/kjy/mp/combo/list/v2?code=");
//        String actualPayMoney = actualPayMoneyResponse.jsonPath().getString("data[0].actualPayMoney");
//        Assert.assertEquals(actualPayMoney,"486","获取付费价格:价格不是486");
    }

    @Test (description = "邀请码/分销码_待支付",priority = 7)
    public void 分销码_待支付() throws IOException {
        //会员类型版本判断
        Map<String, Object> params = new HashMap<String, Object>();
        params.put("t",System.currentTimeMillis());
        Response userVersionResponse = network.getResponse(params,VERSION_INFO);
        int userVersion = userVersionResponse.jsonPath().getInt("data.find {it.openType == 1}.userVersion"); // 找出开启状态的版本类型  1保险  2通用
        Assert.assertEquals(userVersion,2,network.message(params, VERSION_INFO,"会员类型版本判断:判断错误,此版本不是上级对应的版本"));

        //创建支付
        Map<String, Object> payParams = new HashMap<String, Object>();
        payParams.put("userVersion",userVersion);
        payParams.put("comboId","Kj21MTU");
        payParams.put("oaId","1");
        payParams.put("paySource","2");
        payParams.put("sellerFrom","");

        Response orderAppId = network.postResponse(payParams,PAY_ORDERCREATE);
        String appId = orderAppId.jsonPath().getString("data.appId");
        Assert.assertEquals(appId,"wxcb8c36279dd7dff2",network.message(payParams, PAY_ORDERCREATE,"拉起支付:拉起微信支付失败"));  //判断返回的微信调起参数中appId是否正确
    }

//    @Test (description = "邀请码/分销码_成功支付",priority = 8)
//    public void 分销码_成功支付() throws IOException {
//
//    }

    @Test (description = "邀请码/分销码_取消支付",priority = 9)
    public void 分销码_取消支付() throws IOException {
        //会员类型版本判断
        Map<String, Object> params = new HashMap<String, Object>();
        params.put("t",System.currentTimeMillis());
        Response userVersionResponse = network.getResponse(params,VERSION_INFO);
        int userVersion = userVersionResponse.jsonPath().getInt("data.find {it.openType == 1}.userVersion"); // 找出开启状态的版本类型
        Assert.assertEquals(userVersion,2,network.message(params, VERSION_INFO,"会员类型版本判断:判断错误,此版本不是上级对应的版本"));

        //创建支付
        Map<String, Object> payParams = new HashMap<String, Object>();
        payParams.put("userVersion",userVersion);
        payParams.put("comboId","Kj21MTU");
        payParams.put("oaId","1");
        payParams.put("paySource","2");
        payParams.put("sellerFrom","");
        Response orderAppId = network.postResponse(payParams,PAY_ORDERCREATE);
        String tradeNo = orderAppId.jsonPath().getString("data.tradeNo");

        //会员类型版本判断
        Map<String, Object> cancelParams = new HashMap<String, Object>();
        cancelParams.put("tradeNo",tradeNo);
        Response resultResponse = network.getResponse(cancelParams,PAY_ORDERCANCEL);
        String result = resultResponse.jsonPath().getString("desc");
        Assert.assertEquals(result,"OK",network.message(cancelParams, PAY_ORDERCANCEL,"取消支付：取消支付失败"));  //判断返回的微信调起参数中appId是否正确
    }

    @Test (description = "邀请码/分销码_切换会员类型为尊享版",priority = 10)
    public void 分销码_切换为保险版会员类型并成功付款() throws IOException {
        //会员类型版本判断
        Map<String, Object> params = new HashMap<String, Object>();
        params.put("t",System.currentTimeMillis());
        Response userVersionResponse = network.getResponse(params,VERSION_INFO);
        int userVersion = userVersionResponse.jsonPath().getInt("data.find {it.openType == 1}.userVersion"); // 找出开启状态的版本类型
        int changeVersion = userVersion == 1 ? 2 : 1; // 判断当前开启的版本，如果当前版本是1，则改为2，反之；

       //切换版本
        //切换版本
        Map<String, Object> versionParams = new HashMap<String, Object>();
        versionParams.put("targetVersion",changeVersion);
        Response resultResponse = network.postResponse(versionParams,PAY_VERSIONEXCHANGE);
        String result = resultResponse.jsonPath().getString("desc");
        Assert.assertEquals(result,"OK",network.message(versionParams, PAY_VERSIONEXCHANGE,"会员类型切换:切换失败"));  //判断返回的微信调起参数中appId是否正确

//        //会员类型再次判断
        params.put("t",System.currentTimeMillis());
        userVersionResponse = network.getResponse(params,VERSION_INFO);
        userVersion = userVersionResponse.jsonPath().getInt("data.find {it.openType == 1}.userVersion"); // 找出开启状态的版本类型
        Assert.assertEquals(userVersion,changeVersion,network.message(params, VERSION_INFO,"会员类型版本判断:判断错误，此版本为尊享版"));
    }

    @AfterClass
    public static void tearDown(){
        apiCount += 9;
    }



}

